__title__ = 'invain'
__description__ = 'A Python library for getting stock data from Yahoo Finance'
__url__ = 'https://code.inva.in/'
__github_url__ = 'https://github.com/hailfire113/InVaIN'
__version__ = '0.3.1'
__license__ = 'MIT'
